==> scichains-cv-4.2.1-sources.jar: net/algart/executors/modules/opencv/matrices/photo/Inpaint.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2023 Daniel Alievsky, AlgART Laboratory (http://algart.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.algart.executors.modules.opencv.matrices.photo;

import net.algart.executors.modules.opencv.common.VoidResultTwoUMatFilter;
import net.algart.executors.modules.util.opencv.enums.OInpaintAlgorithm;
import org.bytedeco.opencv.global.opencv_photo;
import org.bytedeco.opencv.opencv_core.*;

public final class Inpaint extends VoidResultTwoUMatFilter {
    public static final String INPUT_MASK = "mask";

    private double inpaintRadius = 10;
    private OInpaintAlgorithm algorithm = OInpaintAlgorithm.INPAINT_NS;

    public Inpaint() {
        super(null, INPUT_MASK);
    }

    public double getInpaintRadius() {
        return inpaintRadius;
    }

    public void setInpaintRadius(double inpaintRadius) {
        this.inpaintRadius = nonNegative(inpaintRadius);
    }

    public OInpaintAlgorithm getAlgorithm() {
        return algorithm;
    }

    public void setAlgorithm(OInpaintAlgorithm algorithm) {
        this.algorithm = nonNull(algorithm);
    }

    @Override
    public void process(Mat result, Mat source, Mat secondMat) {
        opencv_photo.inpaint(source, secondMat, result, inpaintRadius, algorithm.code());
    }

    @Override
    public void process(UMat result, UMat source, UMat secondMat) {
        opencv_photo.inpaint(source, secondMat, result, inpaintRadius, algorithm.code());
    }

    @Override
    protected boolean allowInputPackedBits(int inputIndex) {
        return inputIndex == 1;
    }
}

==> scichains-cv-4.3.3-sources.jar: net/algart/executors/modules/opencv/matrices/photo/Inpaint.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2023 Daniel Alievsky, AlgART Laboratory (http://algart.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.algart.executors.modules.opencv.matrices.photo;

import net.algart.executors.modules.opencv.common.VoidResultTwoUMatFilter;
import net.algart.executors.modules.opencv.util.enums.OInpaintAlgorithm;
import org.bytedeco.opencv.global.opencv_photo;
import org.bytedeco.opencv.opencv_core.*;

public final class Inpaint extends VoidResultTwoUMatFilter {
    public static final String INPUT_MASK = "mask";

    private double inpaintRadius = 10;
    private OInpaintAlgorithm algorithm = OInpaintAlgorithm.INPAINT_NS;

    public Inpaint() {
        super(null, INPUT_MASK);
    }

    public double getInpaintRadius() {
        return inpaintRadius;
    }

    public void setInpaintRadius(double inpaintRadius) {
        this.inpaintRadius = nonNegative(inpaintRadius);
    }

    public OInpaintAlgorithm getAlgorithm() {
        return algorithm;
    }

    public void setAlgorithm(OInpaintAlgorithm algorithm) {
        this.algorithm = nonNull(algorithm);
    }

    @Override
    public void process(Mat result, Mat source, Mat secondMat) {
        opencv_photo.inpaint(source, secondMat, result, inpaintRadius, algorithm.code());
    }

    @Override
    public void process(UMat result, UMat source, UMat secondMat) {
        opencv_photo.inpaint(source, secondMat, result, inpaintRadius, algorithm.code());
    }

    @Override
    protected boolean allowInputPackedBits(int inputIndex) {
        return inputIndex == 1;
    }
}
